===============================
m3u-dump
===============================

Tool to dump music playlist and music in playlist.


USAGE
--------
copy music in playlist.m3u to ~/android-music-sync-dir.

::

  $ m3u-dump ~/music/playlist.m3u ~/android-music-sync-dir
